package router

import (
	"net/http"

	"authService/controller/auth"
	"authService/controller/role"
	"authService/controller/user"
	"authService/middleware"

	"github.com/gin-gonic/gin"
	"gogs.uu.mdfitnesscao.com/cuiguohai/sdk/constants"
)

func Init() *gin.Engine {
	router := gin.Default()
	router.Use(middleware.Cors())

	router.GET("/ping", func(c *gin.Context) {
		c.String(http.StatusOK, "The Server is Running")
	})
	// 后台API
	backendApiRouter := router.Group("/backend")
	// 登录
	backendApiRouter.POST("/login", auth.Login)
	backendApiRouter.Use(middleware.Authorize())
	{
		// 退出登录
		backendApiRouter.POST("/logout", auth.Logout)
		// 获取当前登录用户信息
		backendApiRouter.GET("/profile", user.Profile)
		// 修改当前登录用户信息
		backendApiRouter.POST("/profile/update", user.UpdateProfile)

		// |------角色管理
		// 获取角色列表（不要权限）
		backendApiRouter.GET("/role/list", role.List)
		// 获取角色列表（分页）
		backendApiRouter.GET("/role/paginate", middleware.PermissionCheck(constants.PermissionRoleView), role.Paginate)
		// 修改或创建角色
		backendApiRouter.POST("/role/updateOrCreate", middleware.PermissionCheck(constants.PermissionRoleEdit), role.UpdateOrCreate)
		// 删除角色
		backendApiRouter.POST("/role/delete", middleware.PermissionCheck(constants.PermissionRoleDelete), role.Delete)
		// 获取用户权限组列表
		backendApiRouter.GET("/role/permission/list", middleware.PermissionCheck(constants.PermissionRoleEdit), role.ListPermissionGroup)

		// |------用户管理
		// 获取用户列表
		backendApiRouter.GET("/user/paginate", middleware.PermissionCheck(constants.PermissionUserView), user.Paginate)
		// 获取用户列表
		backendApiRouter.GET("/user/list", user.List)
		// 修改或创建用户
		backendApiRouter.POST("/user/updateOrCreate", middleware.PermissionCheck(constants.PermissionUserEdit), user.UpdateOrCreate)
		// 删除用户
		backendApiRouter.POST("/user/delete", middleware.PermissionCheck(constants.PermissionUserDelete), user.Delete)
		// 修改备注信息
		backendApiRouter.POST("/user/updateRemark", middleware.PermissionCheck(constants.PermissionUserEdit), user.UpdateRemark)
	}

	return router
}
