package permission

import (
	"authService/util"
	"authService/validators"
	"os"

	"gogs.uu.mdfitnesscao.com/cuiguohai/sdk/constants"
)

const (
	SystemFlagUser = "User" // 用户平台后台系统
)

// 获取所有权限组
func ListPermissionGroup() []validators.UserPermissionGroup {
	var commonPermissions = []validators.UserPermissionGroup{
		{
			Label: "用户管理",
			Children: []validators.UserPermission{
				{
					Label:          constants.CommonPermissionNames[constants.PermissionUserView].Name,
					Value:          constants.PermissionUserView,
					RequiredValues: []string{},
				},
				{
					Label:          constants.CommonPermissionNames[constants.PermissionUserEdit].Name,
					Value:          constants.PermissionUserEdit,
					RequiredValues: []string{constants.PermissionUserView},
				},
			},
		},
		{
			Label: "角色管理",
			Children: []validators.UserPermission{
				{
					Label:          constants.CommonPermissionNames[constants.PermissionRoleView].Name,
					Value:          constants.PermissionRoleView,
					RequiredValues: []string{},
				},
				{
					Label:          constants.CommonPermissionNames[constants.PermissionRoleEdit].Name,
					Value:          constants.PermissionRoleEdit,
					RequiredValues: []string{constants.PermissionRoleView},
				},
				{
					Label:          constants.CommonPermissionNames[constants.PermissionRoleDelete].Name,
					Value:          constants.PermissionRoleDelete,
					RequiredValues: []string{constants.PermissionRoleView},
				},
			},
		},
	}
	var permissionGroups map[string][]validators.UserPermissionGroup = map[string][]validators.UserPermissionGroup{
		SystemFlagUser: {
			{
				Label: "机构管理",
				Children: []validators.UserPermission{
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionMechanismView].Name,
						Value:          constants.UserPermissionMechanismView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionMechanismEdit].Name,
						Value:          constants.UserPermissionMechanismEdit,
						RequiredValues: []string{constants.UserPermissionMechanismView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionMechanismDelete].Name,
						Value:          constants.UserPermissionMechanismDelete,
						RequiredValues: []string{constants.UserPermissionMechanismView},
					},
				},
			},
			{
				Label: "档案管理",
				Children: []validators.UserPermission{
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionArchivesView].Name,
						Value:          constants.UserPermissionArchivesView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionArchivesEdit].Name,
						Value:          constants.UserPermissionArchivesEdit,
						RequiredValues: []string{constants.UserPermissionArchivesView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionArchivesFormTemplateView].Name,
						Value:          constants.UserPermissionArchivesFormTemplateView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionArchivesFormTemplateEdit].Name,
						Value:          constants.UserPermissionArchivesFormTemplateEdit,
						RequiredValues: []string{constants.UserPermissionArchivesFormTemplateView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionArchivesMechanismConfigView].Name,
						Value:          constants.UserPermissionArchivesMechanismConfigView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionArchivesMechanismConfigEdit].Name,
						Value:          constants.UserPermissionArchivesMechanismConfigEdit,
						RequiredValues: []string{constants.UserPermissionArchivesMechanismConfigView},
					},
				},
			},
			{
				Label: "表单管理",
				Children: []validators.UserPermission{
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionFormView].Name,
						Value:          constants.UserPermissionFormView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionFormEdit].Name,
						Value:          constants.UserPermissionFormEdit,
						RequiredValues: []string{constants.UserPermissionFormView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionFormFieldEdit].Name,
						Value:          constants.UserPermissionFormFieldEdit,
						RequiredValues: []string{constants.UserPermissionFormView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionFormFieldDelete].Name,
						Value:          constants.UserPermissionFormFieldDelete,
						RequiredValues: []string{constants.UserPermissionFormView},
					},
				},
			},
			{
				Label: "数据中心",
				Children: []validators.UserPermission{
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionMedicalDataView].Name,
						Value:          constants.UserPermissionMedicalDataView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionMedicalDataEdit].Name,
						Value:          constants.UserPermissionMedicalDataEdit,
						RequiredValues: []string{constants.UserPermissionMedicalDataView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionMedicalDataRawDataView].Name,
						Value:          constants.UserPermissionMedicalDataRawDataView,
						RequiredValues: []string{constants.UserPermissionMedicalDataView},
					},
				},
			},
			{
				Label: "问卷管理",
				Children: []validators.UserPermission{
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionSurveyView].Name,
						Value:          constants.UserPermissionSurveyView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionSurveyEdit].Name,
						Value:          constants.UserPermissionSurveyEdit,
						RequiredValues: []string{constants.UserPermissionSurveyView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionSurveyAuthorizeView].Name,
						Value:          constants.UserPermissionSurveyAuthorizeView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionSurveyAuthorizeEdit].Name,
						Value:          constants.UserPermissionSurveyAuthorizeEdit,
						RequiredValues: []string{constants.UserPermissionSurveyAuthorizeView},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionSurveyResultView].Name,
						Value:          constants.UserPermissionSurveyResultView,
						RequiredValues: []string{},
					},
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionSurveyResultEdit].Name,
						Value:          constants.UserPermissionSurveyResultEdit,
						RequiredValues: []string{constants.UserPermissionSurveyResultView},
					},
				},
			},
			{
				Label: "敏感数据",
				Children: []validators.UserPermission{
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionDataPrivacyArchivesInfo].Name,
						Value:          constants.UserPermissionDataPrivacyArchivesInfo,
						RequiredValues: []string{constants.UserPermissionArchivesView},
					},
				},
			},
			{
				Label: "数据同步",
				Children: []validators.UserPermission{
					{
						Label:          constants.UserPermissionNames[constants.UserPermissionDataSync].Name,
						Value:          constants.UserPermissionDataSync,
						RequiredValues: []string{},
					},
				},
			},
		},
	}

	// 授权系统的类型
	authType := os.Getenv("AUTH_TYPE")
	currentPermissions := permissionGroups[authType]

	// 将commonPermissions和currentPermissions合并
	return append(commonPermissions, currentPermissions...)
}

// 检查权限
func CheckPermission(permissions []string, permission string) bool {
	return util.InArrayString(permission, permissions)
}
