package user_test

import (
	"authService/model"
	"authService/service/user"
	"authService/util"
	"authService/validators"
	"testing"
)

func TestCreateUser(t *testing.T) {
	util.InitTest()
	var createUser = &validators.User{
		Account:     "hailin",
		Nickname:    "超级管理员",
		Status:      model.UserStatusEnable,
		IsSuper:     model.UserIsSuperTrue,
		Permissions: []string{},
	}
	err := user.UpdateOrCreate(createUser, "qwer1234")
	if err != nil {
		t.Error(err)
	}
}

func TestUpdateUser(t *testing.T) {
	util.InitTest()
	var updateUser = &validators.User{
		ID:          1,
		Account:     "hailinnn",
		Nickname:    "",
		Status:      model.UserStatusDisable,
		IsSuper:     model.UserIsSuperTrue,
		Permissions: []string{"User"},
	}

	err := user.UpdateOrCreate(updateUser, "123456")
	if err != nil {
		t.Error(err)
	}
}

func TestUpdateMySelf(t *testing.T) {
	util.InitTest()
	var updateUser = &validators.User{
		Account:  "hailin",
		Nickname: "哈林",
	}

	err := user.UpdateMySelf(updateUser, "", "", 1)
	if err != nil {
		t.Error(err)
	}
}

func TestPaginate(t *testing.T) {
	util.InitTest()
	users, total := user.Paginate(1, 10, "")
	t.Log(users, total)

	var list []*validators.User
	for _, u := range users {
		list = append(list, user.Format(u))
	}

	t.Log(util.JsonEncode(list))

}
